Package: ic.infer
Title: Inequality Constrained Inference in Linear Normal Situations
Version: 1.1-8
Depends: R(>= 2.5.0)
Imports: quadprog, mvtnorm, boot, kappalab
Suggests: relaimpo
Date: 2026-08-05
Authors@R: person(given = "Ulrike",
                      family = "Groemping",
                      role = c("aut", "cre"),
                      email = "ulrike.groemping@bht-berlin.de")
Description: Implements inequality constrained inference. This includes parameter estimation in normal (linear) models under linear equality and inequality constraints, as well as normal likelihood ratio tests involving inequality-constrained hypotheses. For inequality-constrained linear models, averaging over R-squared for different orderings of regressors is also included.
License: GPL (>= 2)
LazyLoad: yes
URL: https://prof.bht-berlin.de/groemping/
NeedsCompilation: no
Packaged: 2026-08-05 20:32:16 UTC; Gr<c3><b6>mping
Author: Ulrike Groemping [aut, cre]
Maintainer: Ulrike Groemping <ulrike.groemping@bht-berlin.de>
Repository: CRAN
Date/Publication: 2026-08-21 11:20:02 UTC
